<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version="1.0">

<xsl:output method="html" encoding="utf-8"/>

<!-- Standardně se všechny uzly kopírují -->
<xsl:template match="@*|node()">
  <xsl:copy>
    <xsl:apply-templates select="@*|node()"/>
  </xsl:copy>
</xsl:template>

<!-- Vložení stylu do záhlaví -->
<xsl:template match="head">
  <xsl:copy>
    <!-- Zkopírování atributů -->
    <xsl:apply-templates select="@*"/>

    <!-- Zkopírování původního obsahu elementu head -->
    <xsl:apply-templates/>

    <!-- Vložení stylu -->
    <style type="text/css">
      .menu { position: fixed;
              left: 10px;
              width: 182px;
              border: 2px blue solid;
              padding: 2px;
              overflow: auto;
              height: 90%;

              /* IE hack pro fixní pozicování */
              position: expression("absolute");
              top: expression(document.body.scrollTop+this.offsetHeight-this.offsetHeight);
            }
      .content { margin-left: 200px }
    </style>
  </xsl:copy>
</xsl:template>

<!-- Hned za HTML se vloží menu -->
<xsl:template match="body">
  <!-- Kopie elementu body -->
  <xsl:copy>
    <!-- Zkopírování všech atributů -->
    <xsl:apply-templates select="@*"/>
    <!-- Vytvoření menu -->
    <div class="menu">
      <xsl:apply-templates mode="toc"/>
    </div>
    <!-- Původní obsah stránky -->
    <div class="content">
      <xsl:apply-templates select="node()"/>
    </div>
  </xsl:copy>
</xsl:template>

<!-- Položka obsahu z nadpisu h1 --> 
<xsl:template match="h1" mode="toc">
  <xsl:variable name="id">
    <xsl:call-template name="getid"/>
  </xsl:variable>
  <a href="#{$id}">
    <xsl:value-of select="."/>
  </a>
  <br/>
</xsl:template>

<!-- Položka obsahu z nadpisu h2 -->
<xsl:template match="h2" mode="toc">
  <xsl:variable name="id">
    <xsl:call-template name="getid"/>
  </xsl:variable>
  - 
  <a href="#{$id}">
    <xsl:value-of select="."/>
  </a>
  <br/>
</xsl:template>

<!-- Položka obsahu z nadpisu h3 -->
<xsl:template match="h3" mode="toc">
  <xsl:variable name="id">
    <xsl:call-template name="getid"/>
  </xsl:variable>
  --
  <a href="#{$id}">
    <xsl:value-of select="."/>
  </a>
  <br/>
</xsl:template>

<!-- V režimu tvorby obsahu nás zajímají jen nadpisy, ostatní text ignorujeme -->
<xsl:template match="text()" mode="toc"/>

<!-- Doplnění identifikátorů pro odkazy -->
<!-- Doplňují se jen k nadpisům, které identifikátor ještě nemají -->
<xsl:template match="h1[not(@id)] | h2[not(@id)] | h3[not(@id)]">
  <xsl:copy>
    <!-- Zkopírování všech atributů -->
    <xsl:apply-templates select="@*"/>
    <!-- Doplnění ID -->
    <xsl:attribute name="id">
      <xsl:value-of select="generate-id()"/>
    </xsl:attribute>
    <!-- Zkopírování původního obsahu elementu -->
    <xsl:apply-templates select="node()"/>
  </xsl:copy>
</xsl:template>

<!-- Vrátí bud skutečné nebo automaticky vygenerované ID 
     pro aktuální element -->
<xsl:template name="getid">
  <xsl:choose>
    <xsl:when test="@id">
      <xsl:value-of select="@id"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="generate-id()"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

</xsl:stylesheet>